@@ -1,13 +1,17 @@
 let { copy, ensureDir, readFile, remove } = require('fs-extra')
 let { equal, match, ok, throws } = require('uvu/assert')
-let { execSync } = require('child_process')
+let { execSync } = require('node:child_process')
 let { nanoid } = require('nanoid/non-secure')
-let { tmpdir } = require('os')
+let { tmpdir } = require('node:os')
 let { test } = require('uvu')
-let { join } = require('path')
+let { join } = require('node:path')
 
 let updateDb = require('..')
 
+// Check if HADOOP_HOME is set to determine if this is running in a Hadoop environment
+const IsHadoopExists = !! process.env.HADOOP_HOME
+const yarnCommand = IsHadoopExists ? 'yarnpkg' : 'yarn'
+
 let testDir
 test.after.each(async () => {
   process.chdir(__dirname)
@@ -224,19 +228,24 @@ test('updates caniuse-lite for yarn with workspaces', async () => {
   checkYarnLockfile(dir)
 })
 
-test('updates caniuse-lite for yarn v2', async () => {
-  let dir = await chdir('update-yarn-v2', 'package.json', 'yarn.lock')
-  execSync('yarn set version berry')
-  match(
-    runUpdate(),
-    `Latest version:     ${caniuse.version}\n` +
-      'Updating caniuse-lite version\n' +
-      '$ yarn up -R caniuse-lite\n' +
-      'caniuse-lite has been successfully updated\n'
-  )
-  checkYarnLockfile(dir, 2)
-  execSync('yarn set version classic')
-})
+if (
+  !process.version.startsWith('v14.') &&
+  !process.version.startsWith('v16.')
+) {
+  test('updates caniuse-lite for yarn v2', async () => {
+    let dir = await chdir('update-yarn-v2', 'package.json', 'yarn.lock')
+    execSync('yarn set version berry')
+    match(
+      runUpdate(),
+      `Latest version:     ${caniuse.version}\n` +
+        'Updating caniuse-lite version\n' +
+        '$ yarn up -R caniuse-lite\n' +
+        'caniuse-lite has been successfully updated\n'
+    )
+    checkYarnLockfile(dir, 2)
+    execSync(yarnCommand + ' set version classic')
+  })
+}
 
 test('updates caniuse-lite for pnpm', async () => {
   let dir = await chdir('update-pnpm', 'package.json', 'pnpm-lock.yaml')
@@ -251,7 +260,7 @@ test('updates caniuse-lite for pnpm', async () => {
   let lock = (await readFile(join(dir, 'pnpm-lock.yaml'))).toString()
   ok(
     lock.includes(`/caniuse-lite/${caniuse.version}:`) ||
-      lock.includes(`/caniuse-lite@${caniuse.version}:`)
+      lock.includes(`caniuse-lite@${caniuse.version}:`)
   )
 })
 
